#
# HLstats Database Installation file
# ----------------------------------
#
# To install, type:
#
# 	mysql hlstats < hlstats.sql
#


#
# Create database (uncomment if you want this)
#

#CREATE DATABASE IF NOT EXISTS hlstats;


#
# Table structure for table 'hlstats_Actions'
#

CREATE TABLE hlstats_Actions (
  id int(10) unsigned NOT NULL auto_increment,
  game varchar(16) DEFAULT 'valve' NOT NULL,
  code varchar(64) DEFAULT '' NOT NULL,
  reward_player int(11) DEFAULT '10' NOT NULL,
  reward_team int(11) DEFAULT '0' NOT NULL,
  team varchar(32) DEFAULT '' NOT NULL,
  description varchar(128),
  for_PlayerActions enum('0', '1') DEFAULT '0' NOT NULL,
  for_PlayerPlayerActions enum('0', '1') DEFAULT '0' NOT NULL,
  for_TeamActions enum('0', '1') DEFAULT '0' NOT NULL,
  for_WorldActions enum('0', '1') DEFAULT '0' NOT NULL,
  PRIMARY KEY (id),
  KEY code (code),
  UNIQUE gamecode (game,code)
);

#
# Table structure for table 'hlstats_Awards'
#

CREATE TABLE hlstats_Awards (
  awardId int(10) unsigned NOT NULL auto_increment,
  awardType enum('W','O') DEFAULT 'W' NOT NULL,
  game varchar(32) DEFAULT 'valve' NOT NULL,
  code varchar(128) DEFAULT '' NOT NULL,
  name varchar(128) DEFAULT '' NOT NULL,
  verb varchar(64) DEFAULT '' NOT NULL,
  d_winner_id int(10) unsigned,
  d_winner_count int(10) unsigned,
  PRIMARY KEY (awardId),
  UNIQUE KEY code (game, awardType, code)
);

#
# Table structure for table 'hlstats_Clans'
#

CREATE TABLE hlstats_Clans (
  clanId int(10) unsigned NOT NULL auto_increment,
  tag varchar(32) DEFAULT '' NOT NULL,
  name varchar(128) DEFAULT '' NOT NULL,
  homepage varchar(64) DEFAULT '' NOT NULL,
  game varchar(16) DEFAULT '' NOT NULL,
  PRIMARY KEY (clanId),
  KEY game (game),
  UNIQUE tag (game,tag)
);

#
# Table structure for table 'hlstats_ClanTags'
#

CREATE TABLE hlstats_ClanTags (
  id int(10) unsigned NOT NULL auto_increment,
  pattern varchar(64) DEFAULT '' NOT NULL,
  position enum('EITHER','START','END') DEFAULT 'EITHER' NOT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY pattern(pattern)
);

#
# Dumping data for table 'hlstats_ClanTags'
#

INSERT INTO hlstats_ClanTags VALUES (1,'[AXXXXX]','EITHER');
INSERT INTO hlstats_ClanTags VALUES (2,'|AXXXXX|','EITHER');
INSERT INTO hlstats_ClanTags VALUES (3,'(AXXXXX)','EITHER');
INSERT INTO hlstats_ClanTags VALUES (4,'{AXXXXX}','EITHER');
INSERT INTO hlstats_ClanTags VALUES (5,'-=AXXX=-','START');
INSERT INTO hlstats_ClanTags VALUES (6,'=AXXXXX=','START');
INSERT INTO hlstats_ClanTags VALUES (7,'-AXXXXX-','START');
INSERT INTO hlstats_ClanTags VALUES (8,'=[AXXXX]=','START');
INSERT INTO hlstats_ClanTags VALUES (9,'-=|AXXXXXX|=-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (10,'-=[AXXXXXX]=-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (11,'-=]AXXXXXX[=-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (12,'~{|AXXXXXX|}~','EITHER');
INSERT INTO hlstats_ClanTags VALUES (13,'-|-AXXXXXX-|-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (14,'-(AXXXXXX)-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (15,'::AXXXXXX::','EITHER');
INSERT INTO hlstats_ClanTags VALUES (16,'<<AXXXXXX>>','EITHER');
INSERT INTO hlstats_ClanTags VALUES (17,'{{AXXXXXX}}','EITHER');
INSERT INTO hlstats_ClanTags VALUES (18,'((AXXXXXX))','EITHER');
INSERT INTO hlstats_ClanTags VALUES (19,'.|AXXXXXX|.','EITHER');
INSERT INTO hlstats_ClanTags VALUES (20,'--AXXXXXX--','EITHER');
INSERT INTO hlstats_ClanTags VALUES (21,'-)AXXXXXX(-','EITHER');
INSERT INTO hlstats_ClanTags VALUES (22,'/AXXXXXX\\','EITHER');
INSERT INTO hlstats_ClanTags VALUES (23,'//AXXXXXX\\\\','EITHER');
INSERT INTO hlstats_ClanTags VALUES (24,'_AXXXXXX_','EITHER');
INSERT INTO hlstats_ClanTags VALUES (25,'_=|AXXXXXX|=_','EITHER');
INSERT INTO hlstats_ClanTags VALUES (26,'*AXXXXXX*','EITHER');
INSERT INTO hlstats_ClanTags VALUES (27,'.:AXXXXXX:','START');
INSERT INTO hlstats_ClanTags VALUES (28,'[(AXXXXXX)]','EITHER');

#
# Table structure for table 'hlstats_Games'
#

CREATE TABLE hlstats_Games (
  code varchar(16) DEFAULT '' NOT NULL,
  name varchar(128) DEFAULT '' NOT NULL,
  hidden enum('0', '1') DEFAULT '0' NOT NULL,
  PRIMARY KEY (code)
);

#
# Table structure for table 'hlstats_HostGroups'
#

CREATE TABLE hlstats_HostGroups (
  id int(11) NOT NULL auto_increment,
  pattern varchar(128) DEFAULT '' NOT NULL,
  name varchar(128) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Dumping data for table 'hlstats_HostGroups'
#

INSERT INTO hlstats_HostGroups VALUES (NULL, '.aol.com', 'AOL');

#
# Table structure for table 'hlstats_Options'
#

CREATE TABLE hlstats_Options (
  keyname varchar(32) DEFAULT '' NOT NULL,
  value varchar(255) DEFAULT '' NOT NULL,
  PRIMARY KEY (keyname)
);

#
# Dumping data for table 'hlstats_Options'
#

INSERT INTO hlstats_Options VALUES ('font_normal','<font face=\"Verdana, Arial, sans-serif\" size=2 class=\"fontNormal\">');
INSERT INTO hlstats_Options VALUES ('fontend_normal','</font>');
INSERT INTO hlstats_Options VALUES ('font_small','<font face=\"Verdana, Arial, sans-serif\" size=1 class=\"fontSmall\">');
INSERT INTO hlstats_Options VALUES ('fontend_small','</font>');
INSERT INTO hlstats_Options VALUES ('font_title','<font face=\"Arial, sans-serif\" size=4 class=\"fontTitle\"><b>');
INSERT INTO hlstats_Options VALUES ('fontend_title','</b></font>');
INSERT INTO hlstats_Options VALUES ('table_bgcolor1','#15154D');
INSERT INTO hlstats_Options VALUES ('table_bgcolor2','#161652');
INSERT INTO hlstats_Options VALUES ('table_wpnbgcolor','#000000');
INSERT INTO hlstats_Options VALUES ('table_border','#001B73');
INSERT INTO hlstats_Options VALUES ('table_head_text','#EEEEEE');
INSERT INTO hlstats_Options VALUES ('table_head_bgcolor','#002E8A');
INSERT INTO hlstats_Options VALUES ('location_link','#FFFFFF');
INSERT INTO hlstats_Options VALUES ('location_text','#FFFFFF');
INSERT INTO hlstats_Options VALUES ('location_bgcolor','#003399');
INSERT INTO hlstats_Options VALUES ('body_leftmargin','10');
INSERT INTO hlstats_Options VALUES ('body_topmargin','15');
INSERT INTO hlstats_Options VALUES ('body_alink','#FFBB00');
INSERT INTO hlstats_Options VALUES ('body_link','#FF9900');
INSERT INTO hlstats_Options VALUES ('body_text','#EEEEEE');
INSERT INTO hlstats_Options VALUES ('body_vlink','#FF9000');
INSERT INTO hlstats_Options VALUES ('body_bgcolor','#0C1D40');
INSERT INTO hlstats_Options VALUES ('body_background','');
INSERT INTO hlstats_Options VALUES ('imgdir','hlstatsimg');
INSERT INTO hlstats_Options VALUES ('contact','mailto:admin@site.dom');
INSERT INTO hlstats_Options VALUES ('sitename','Some Site');
INSERT INTO hlstats_Options VALUES ('siteurl','http://www.site.dom');

#
# Table structure for table 'hlstats_Players'
#

CREATE TABLE hlstats_Players (
  playerId int(10) unsigned NOT NULL auto_increment,
  lastName varchar(64) DEFAULT '' NOT NULL,
  clan int(10) unsigned DEFAULT '0' NOT NULL,
  kills int(11) DEFAULT '0' NOT NULL,
  deaths int(11) DEFAULT '0' NOT NULL,
  suicides int(11) DEFAULT '0' NOT NULL,
  skill int(11) DEFAULT '1000' NOT NULL,
  fullName varchar(128),
  email varchar(128),
  homepage varchar(128),
  icq int(10) unsigned,
  game varchar(16) DEFAULT '' NOT NULL,
  hideranking int(1) unsigned DEFAULT '0' NOT NULL,
  PRIMARY KEY (playerId),
  KEY clan (clan),
  KEY game (game)
);

#
# Table structure for table 'hlstats_PlayerNames'
#

CREATE TABLE hlstats_PlayerNames (
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  name varchar(64) DEFAULT '' NOT NULL,
  lastuse datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  numuses int(10) unsigned DEFAULT '0' NOT NULL,
  kills int(11) DEFAULT '0' NOT NULL,
  deaths int(11) DEFAULT '0' NOT NULL,
  suicides int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (playerId,name)
);

#
# Table structure for table 'hlstats_PlayerUniqueIds'
#

CREATE TABLE hlstats_PlayerUniqueIds (
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  uniqueId varchar(64) DEFAULT '' NOT NULL,
  game varchar(16) DEFAULT '' NOT NULL,
  merge int(10) unsigned,
  KEY playerId (playerId),
  PRIMARY KEY (uniqueId,game)
);

#
# Table structure for table 'hlstats_Roles'
#

CREATE TABLE hlstats_Roles (
  roleId int(10) unsigned NOT NULL auto_increment,
  game varchar(16) DEFAULT 'valve' NOT NULL,
  code varchar(32) DEFAULT '' NOT NULL,
  name varchar(64) DEFAULT '' NOT NULL,
  hidden enum('0', '1') DEFAULT '0' NOT NULL,
  PRIMARY KEY (roleId),
  UNIQUE gamecode (game,code)
);

#
# Table structure for table 'hlstats_Servers'
#

CREATE TABLE hlstats_Servers (
  serverId int(10) unsigned NOT NULL auto_increment,
  address varchar(15) DEFAULT '' NOT NULL,
  port int(5) unsigned DEFAULT '0' NOT NULL,
  name varchar(64) DEFAULT '' NOT NULL,
  game varchar(16) DEFAULT 'valve' NOT NULL,
  publicaddress varchar(64) DEFAULT '' NOT NULL,
  statusurl varchar(255),
  rcon_password varchar(48) DEFAULT '' NOT NULL,
  PRIMARY KEY (serverId),
  UNIQUE addressport (address,port)
);

#
# Table structure for table 'hlstats_Teams'
#

CREATE TABLE hlstats_Teams (
  teamId int(10) unsigned NOT NULL auto_increment,
  game varchar(16) DEFAULT 'valve' NOT NULL,
  code varchar(32) DEFAULT '' NOT NULL,
  name varchar(64) DEFAULT '' NOT NULL,
  hidden enum('0', '1') DEFAULT '0' NOT NULL,
  PRIMARY KEY (teamId),
  UNIQUE gamecode (game,code)
);

#
# Table structure for table 'hlstats_Users'
#

CREATE TABLE hlstats_Users (
  username varchar(16) DEFAULT '' NOT NULL,
  password varchar(16) DEFAULT '' NOT NULL,
  acclevel int(11) DEFAULT '0' NOT NULL,
  playerId int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (username)
);

#
# Dumping data for table 'hlstats_Users'
#

INSERT INTO hlstats_Users VALUES ('admin',PASSWORD('123456'),100,0);

#
# Table structure for table 'hlstats_Weapons'
#

CREATE TABLE hlstats_Weapons (
  weaponId int(10) unsigned NOT NULL auto_increment,
  game varchar(16) DEFAULT 'valve' NOT NULL,
  code varchar(32) DEFAULT '' NOT NULL,
  name varchar(64) DEFAULT '' NOT NULL,
  modifier float(10,2) DEFAULT '1.00' NOT NULL,
  PRIMARY KEY (weaponId),
  UNIQUE gamecode (game,code)
);












##
## Events Tables
##


#
# Table structure for table 'hlstats_Events_Admin'
#

CREATE TABLE hlstats_Events_Admin (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(32) DEFAULT '' NOT NULL,
  type varchar(32) DEFAULT 'Unknown' NOT NULL,
  message varchar(128) DEFAULT '' NOT NULL,
  playerName varchar(128) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_ChangeName'
#

CREATE TABLE hlstats_Events_ChangeName (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  oldName varchar(64) DEFAULT '' NOT NULL,
  newName varchar(64) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_ChangeRole'
#

CREATE TABLE hlstats_Events_ChangeRole (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  role varchar(32) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_ChangeTeam'
#

CREATE TABLE hlstats_Events_ChangeTeam (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  team varchar(32) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Connects'
#

CREATE TABLE hlstats_Events_Connects (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(32) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  ipAddress varchar(15) DEFAULT '' NOT NULL,
  hostname varchar(128) DEFAULT '' NOT NULL,
  hostgroup varchar(128) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Disconnects'
#

CREATE TABLE hlstats_Events_Disconnects (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Entries'
#

CREATE TABLE hlstats_Events_Entries (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Frags'
#

CREATE TABLE hlstats_Events_Frags (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  killerId int(10) unsigned DEFAULT '0' NOT NULL,
  victimId int(10) unsigned DEFAULT '0' NOT NULL,
  weapon varchar(20) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_PlayerActions'
#

CREATE TABLE hlstats_Events_PlayerActions (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  actionId int(10) unsigned DEFAULT '0' NOT NULL,
  bonus int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_PlayerPlayerActions'
#

CREATE TABLE hlstats_Events_PlayerPlayerActions (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  victimId int(10) unsigned DEFAULT '0' NOT NULL,
  actionId int(10) unsigned DEFAULT '0' NOT NULL,
  bonus int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Rcon'
#

CREATE TABLE hlstats_Events_Rcon (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(32) DEFAULT '' NOT NULL,
  type varchar(6) DEFAULT 'UNK' NOT NULL,
  remoteIp varchar(15) DEFAULT '' NOT NULL,
  password varchar(32) DEFAULT '' NOT NULL,
  command varchar(128) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Suicides'
#

CREATE TABLE hlstats_Events_Suicides (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  weapon varchar(20) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_TeamBonuses'
#

CREATE TABLE hlstats_Events_TeamBonuses (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(32) DEFAULT '' NOT NULL,
  playerId int(10) unsigned DEFAULT '0' NOT NULL,
  actionId int(10) unsigned DEFAULT '0' NOT NULL,
  bonus int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Teamkills'
#

CREATE TABLE hlstats_Events_Teamkills (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  serverId int(10) unsigned DEFAULT '0' NOT NULL,
  map varchar(20) DEFAULT '' NOT NULL,
  killerId int(10) unsigned DEFAULT '0' NOT NULL,
  victimId int(10) unsigned DEFAULT '0' NOT NULL,
  weapon varchar(20) DEFAULT '' NOT NULL,
  PRIMARY KEY (id)
);

#
# Table structure for table 'hlstats_Events_Statsme'
#

CREATE TABLE hlstats_Events_Statsme (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime NOT NULL default '0000-00-00 00:00:00',
  serverId int(10) unsigned NOT NULL default '0',
  map varchar(32) NOT NULL default '',
  playerId int(10) unsigned NOT NULL default '0',
  weapon varchar(32) NOT NULL default '',
  shots int(6) unsigned NOT NULL default '0',
  hits int(6) unsigned NOT NULL default '0',
  headshots int(6) unsigned NOT NULL default '0',
  damage int(6) unsigned NOT NULL default '0',
  kills int(6) unsigned NOT NULL default '0',
  deaths int(6) unsigned NOT NULL default '0',
  KEY playerId (playerId),
  PRIMARY KEY  (id)
) TYPE=MyISAM;

#
# Table structure for table 'hlstats_Events_Statsme2'
#

CREATE TABLE hlstats_Events_Statsme2 (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime NOT NULL default '0000-00-00 00:00:00',
  serverId int(10) unsigned NOT NULL default '0',
  map varchar(32) NOT NULL default '',
  playerId int(10) unsigned NOT NULL default '0',
  weapon varchar(32) NOT NULL default '',
  head int(6) unsigned NOT NULL default '0',
  chest int(6) unsigned NOT NULL default '0',
  stomach int(6) unsigned NOT NULL default '0',
  leftarm int(6) unsigned NOT NULL default '0',
  rightarm int(6) unsigned NOT NULL default '0',
  leftleg int(6) unsigned NOT NULL default '0',
  rightleg int(6) unsigned NOT NULL default '0',
  KEY playerId (playerId),
  PRIMARY KEY  (id)
) TYPE=MyISAM;

#
# Table structure for table 'hlstats_Events_StatsmeTime'
#

CREATE TABLE hlstats_Events_StatsmeTime (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime NOT NULL default '0000-00-00 00:00:00',
  serverId int(10) unsigned NOT NULL default '0',
  map varchar(32) NOT NULL default '',
  playerId int(10) unsigned NOT NULL default '0',
  time time NOT NULL default '00:00:00',
  KEY playerId (playerId),
  PRIMARY KEY  (id)
) TYPE=MyISAM;

#
# Table structure for table 'hlstats_Events_StatsmeLatency'
#

CREATE TABLE hlstats_Events_StatsmeLatency (
  id int(10) unsigned NOT NULL auto_increment,
  eventTime datetime NOT NULL default '0000-00-00 00:00:00',
  serverId int(10) unsigned NOT NULL default '0',
  map varchar(32) NOT NULL default '',
  playerId int(10) unsigned NOT NULL default '0',
  ping int(6) unsigned NOT NULL default '0',
  KEY playerId (playerId),
  PRIMARY KEY  (id)
) TYPE=MyISAM;

